@@ -19,7 +19,7 @@ from revsymg.exceptions import (
 )
 from revsymg.graphs._adjancy_table import _AdjsIndT
 from revsymg.graphs.attributes import AttributesContainer
-from revsymg.lib.index_lib import (
+from revsymg.index_lib import (
     PRED_IND,
     SUCC_IND,
     EIndIndT,
@@ -49,9 +49,9 @@ class SplitStrandsEdges():
         """The Initializer."""
         # The number of current edges
         self._card_e: int = 0
-        # The last edges integer identifier ---
+        # The last edges integer identifier
         self._ind_e: IndexT = -1
-        # Adjancies table ---------------------------------
+        # Adjacency table
         #
         # [PREDS_IND]: Predecessors lists
         #   [v_index]: [(u_ind, e_ind) | (u_ind, v_ind) in E]
